@@ -10,83 +10,79 @@ library(roger)
 ###
 ### Tests for roger_checkreq
 ###
-stopifnot(
+stopifnot(exprs = {
     identical(roger_checkreq(.debugOnly = TRUE),
               r"(roger checkreq)")
-)
-stopifnot(
     identical(roger_checkreq("~/foobar", .debugOnly = TRUE),
               paste0("roger checkreq --file=",
                      shQuote(paste0(path.expand("~"), "/foobar"))))
-)
-stopifnot(
     identical(roger_checkreq("foo bar", .debugOnly = TRUE),
               paste0("roger checkreq --file=",
                      shQuote("foo bar")))
-)
+})
 
 ###
 ### Tests for roger_clone
 ###
-stopifnot(
-    identical(roger_clone("project", "[0-9]{9}_[Ll]ab", .debugOnly = TRUE),
+stopifnot(exprs = {
+    identical(roger_clone("[0-9]{9}_[Ll]ab", "project", .debugOnly = TRUE),
               paste0("roger clone ",
-                     shQuote("[0-9]{9}_[Ll]ab"), " ",
+                     "-- ", shQuote("[0-9]{9}_[Ll]ab"), " ",
+                     shQuote("project")))
+    identical(roger_clone(pat = "[0-9]{9}_[Ll]ab", "project", quiet = TRUE,
+                          .debugOnly = TRUE),
+              paste0("roger clone --quiet ",
+                     "-- ", shQuote("[0-9]{9}_[Ll]ab"), " ",
                      shQuote("project")))
-)
-stopifnot(
     identical(roger_clone("project", pattern = "[0-9]{9} [Ll]ab",
-                          page_limit = 500, api = "bitbucket", .debugOnly = TRUE),
-              paste0("roger clone --page-limit=",
-                     shQuote("500"), " --api=",
-                     shQuote("bitbucket"), " ",
-                     shQuote("[0-9]{9} [Ll]ab"), " ",
+                          api = "gitlab", .debugOnly = TRUE),
+              paste0("roger clone --api=",
+                     shQuote("gitlab"), " ",
+                     "-- ", shQuote("[0-9]{9} [Ll]ab"), " ",
                      shQuote("project")))
-)
-stopifnot(
     identical(roger_clone(pattern = ".*", machine = "x.y.z", pro = "project",
                           .debugOnly = TRUE),
               paste0("roger clone --machine=",
                      shQuote("x.y.z"), " ",
-                     shQuote(".*"), " ",
+                     "-- ", shQuote(".*"), " ",
                      shQuote("project")))
-)
-stopifnot(
-    identical(roger_clone("project", "[0-9]{9}_[Ll]ab",
+    identical(roger_clone(pattern = ".*", machine = "x.y.z", pro = "project",
+                    rogerrc_file = "~/.foo", .debugOnly = TRUE),
+              paste0("roger clone --rogerrc-file=",
+                     shQuote(path.expand("~/.foo")), " --machine=",
+                     shQuote("x.y.z"), " ",
+                     "-- ", shQuote(".*"), " ",
+                     shQuote("project")))
+    identical(roger_clone(pro = "project", "[0-9]{9}_[Ll]ab",
                           curl_options = c("-a", "-b"), .debugOnly = TRUE),
               paste0("roger clone -a -b ",
-                     shQuote("[0-9]{9}_[Ll]ab"), " ",
+                     "-- ", shQuote("[0-9]{9}_[Ll]ab"), " ",
                      shQuote("project")))
-)
+})
 
 ###
 ### Tests for roger_grade
 ###
-stopifnot(
-    identical(roger_grade(".", .debugOnly = TRUE),
+stopifnot(exprs = {
+    identical(roger_grade(.debugOnly = TRUE),
               paste0("roger grade ",
-                     shQuote(".")))
-)
-stopifnot(
+                     shQuote(getwd())))
+    identical(roger_grade(quiet = TRUE, .debugOnly = TRUE),
+              paste0("roger grade --quiet ",
+                     shQuote(getwd())))
     identical(roger_grade("[0-9]*/", conf = "gradeconf-lab", .debugOnly = TRUE),
               paste0("roger grade --config-file=",
                      shQuote("gradeconf-lab"), " ",
                      shQuote("[0-9]*/")))
-)
-stopifnot(
     identical(roger_grade("[0-9]*/", time_limit = "2001-05-08 18:00:00",
                           output = "grading.txt", .debugOnly = TRUE),
               paste0("roger grade --time-limit=",
                      shQuote("2001-05-08 18:00:00"), " --output-file=",
                      shQuote("grading.txt"), " ",
                      shQuote("[0-9]*/")))
-)
-stopifnot(
-    identical(roger_grade(".", detached_head = TRUE, .debugOnly = TRUE),
+    identical(roger_grade(detached_head = TRUE, .debugOnly = TRUE),
               paste0("roger grade --detached-head ",
-                     shQuote(".")))
-)
-stopifnot(
+                     shQuote(getwd())))
     identical(roger_grade("[0-9]*/", detached_head = TRUE,
                           time_limit = "2042-10-11 23:59:59",
                           output_file = "CORRECTION.txt",
@@ -95,34 +91,33 @@ stopifnot(
                      shQuote("2042-10-11 23:59:59"), " --output-file=",
                      shQuote("CORRECTION.txt"), " --detached-head ",
                      shQuote("[0-9]*/")))
-)
+})
 
 ###
 ### Tests for roger_push
 ###
-stopifnot(
+stopifnot(exprs = {
+    identical(roger_push("grading",
+                   .debugOnly = TRUE),
+              paste0("roger push ",
+                     shQuote("grading"), " ",
+                     shQuote(getwd())))
     identical(roger_push("[0-9]*/", branch = "grading",
-                         .debugOnly = TRUE),
+                   .debugOnly = TRUE),
               paste0("roger push ",
                      shQuote("grading"), " ",
                      shQuote("[0-9]*/")))
-)
-stopifnot(
     identical(roger_push("[0-9]*/", branch = "grading", create = TRUE,
                          .debugOnly = TRUE),
               paste0("roger push --create ",
                      shQuote("grading"), " ",
                      shQuote("[0-9]*/")))
-)
-stopifnot(
     identical(roger_push("[0-9]*/", branch = "grading", "GRADING.txt",
                          create = TRUE, .debugOnly = TRUE),
               paste0("roger push --create --file=",
                      shQuote("GRADING.txt"), " ",
                      shQuote("grading"), " ",
                      shQuote("[0-9]*/")))
-)
-stopifnot(
     identical(roger_push("[0-9]*/", branch = "grading", file = "GRADING.txt",
                          create = TRUE, add_file = "foo.txt",
                          .debugOnly = TRUE),
@@ -131,8 +126,6 @@ stopifnot(
                      shQuote("foo.txt"), " ",
                      shQuote("grading"), " ",
                      shQuote("[0-9]*/")))
-)
-stopifnot(
     identical(roger_push("[0-9]*/", branch = "grading", file = "GRADING.txt",
                          create = TRUE, add_file = c("foo", "bar"),
                          .debugOnly = TRUE),
@@ -142,16 +135,12 @@ stopifnot(
                      shQuote("bar"), " ",
                      shQuote("grading"), " ",
                      shQuote("[0-9]*/")))
-)
-stopifnot(
     identical(roger_push("[0-9]*/", branch = "grading",
                          message = "foo", .debugOnly = TRUE),
               paste0("roger push --message=",
                      shQuote("foo"), " ",
                      shQuote("grading"), " ",
                      shQuote("[0-9]*/")))
-)
-stopifnot(
     identical(roger_push("[0-9]*/", branch = "grading",
                          message = c("foo", "bar"), .debugOnly = TRUE),
               paste0("roger push --message=",
@@ -159,50 +148,46 @@ stopifnot(
                      shQuote("bar"), " ",
                      shQuote("grading"), " ",
                      shQuote("[0-9]*/")))
-)
+})
 
 ###
 ### Tests for roger_switch
 ###
-stopifnot(
-    identical(roger_switch("foobar", "main", .debugOnly = TRUE),
+stopifnot(exprs = {
+    identical(roger_switch("main", .debugOnly = TRUE),
+              paste0("roger switch ",
+                     shQuote("main"), " ",
+                     shQuote(getwd())))
+    identical(roger_switch("main", "foobar", .debugOnly = TRUE),
               paste0("roger switch ",
                      shQuote("main"), " ",
                      shQuote("foobar")))
-)
-stopifnot(
-    identical(roger_switch("foobar", "main", TRUE,
+    identical(roger_switch(repos = "foobar", "main", TRUE,
+                     .debugOnly = TRUE),
+              paste0("roger switch --quiet ",
+                     shQuote("main"), " ",
+                     shQuote("foobar")))
+    identical(roger_switch("main", quiet = TRUE, "foobar",
                            .debugOnly = TRUE),
               paste0("roger switch --quiet ",
                      shQuote("main"), " ",
                      shQuote("foobar")))
-)
-stopifnot(
-    identical(roger_switch("foobar", quiet = TRUE, "main",
-                           .debugOnly = TRUE),
-              paste0("roger switch --quiet ",
-                     shQuote("main"), " ",
-                     shQuote("foobar")))
-)
+})
 
 ###
 ### Tests for roger_validate
 ###
-stopifnot(
-    identical(roger_validate(".", .debugOnly = TRUE),
+stopifnot(exprs = {
+    identical(roger_validate(.debugOnly = TRUE),
               paste0("roger validate ",
-                     shQuote(".")))
-)
-stopifnot(
-    identical(roger_validate(".", "validateconf-foo",
+                     shQuote(getwd())))
+    identical(roger_validate(config_file = "validateconf-foo",
                              .debugOnly = TRUE),
               paste0("roger validate --config-file=",
                      shQuote("validateconf-foo"), " ",
-                     shQuote(".")))
-)
-stopifnot(
-    identical(roger_validate(".", check = FALSE,
+                     shQuote(getwd())))
+    identical(roger_validate("foo", check = FALSE,
                              .debugOnly = TRUE),
               paste0("roger validate --no-check-local-repos ",
-                     shQuote(".")))
-)
+                     shQuote("foo")))
+})
